@@ -2,12 +2,13 @@
 from pymadng import MAD
 import os, numpy as np
 
-current_dir = os.path.dirname(os.path.realpath(__file__)) + "/"
+orginal_dir = os.getcwd()
+os.chdir(os.path.dirname(os.path.realpath(__file__)))
 
 mad = MAD() #Not being in context manager makes not difference.
 
 #Just boring setup (in lots of other examples)
-mad.MADX.load(f"'{current_dir}fodo.seq'", f"'{current_dir}fodo.mad'")
+mad.MADX.load(f"'fodo.seq'", f"'fodo.mad'")
 mad["seq"] = mad.MADX.seq
 mad.seq.beam = mad.beam()
 
@@ -34,4 +35,6 @@ print(type(myMatrix.eval())) #A 4x4 matrix!
 myMatrix = myMatrix.eval() #Store the matrix permanantly
 
 mad["myMatrix"] = mad.MAD.matrix(4).seq()
-print(mad.myMatrix, np.all(myMatrix == mad.myMatrix))
\ No newline at end of file
+print(mad.myMatrix, np.all(myMatrix == mad.myMatrix))
+
+os.chdir(orginal_dir)
\ No newline at end of file
